# FaxsuiteResTfulApi.JobDetailsApi

All URIs are relative to *https://service.fax-api.de/4.0/rest*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getJob**](JobDetailsApi.md#getJob) | **GET** /jobs/{id} | /jobs/{id}
[**getJobNotifications**](JobDetailsApi.md#getJobNotifications) | **GET** /jobs/{id}/notifications | /jobs/{id}/notifications
[**getJobPreviews**](JobDetailsApi.md#getJobPreviews) | **GET** /jobs/{id}/preview | /jobs/{id}/preview
[**getJobRecipients**](JobDetailsApi.md#getJobRecipients) | **GET** /jobs/{id}/recipients | /jobs/{id}/recipients
[**getJobTemplates**](JobDetailsApi.md#getJobTemplates) | **GET** /jobs/{id}/templates | /jobs/{id}/templates
[**putJob**](JobDetailsApi.md#putJob) | **PUT** /jobs/{id} | /jobs/{id}

<a name="getJob"></a>
# **getJob**
> Job getJob(id)

/jobs/{id}

Description: Obtain information of a specific job

### Example
```javascript
import {FaxsuiteResTfulApi} from 'faxsuite_res_tful_api';
let defaultClient = FaxsuiteResTfulApi.ApiClient.instance;

// Configure API key authorization: ApiAuthKey
let ApiAuthKey = defaultClient.authentications['ApiAuthKey'];
ApiAuthKey.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.apiKeyPrefix = 'Token';

let apiInstance = new FaxsuiteResTfulApi.JobDetailsApi();
let id = "id_example"; // String | Identification number (UUID) of the job

apiInstance.getJob(id, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Identification number (UUID) of the job | 

### Return type

[**Job**](Job.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getJobNotifications"></a>
# **getJobNotifications**
> Notifications getJobNotifications(id)

/jobs/{id}/notifications

Description: To obtain a list of notifications to a specific job

### Example
```javascript
import {FaxsuiteResTfulApi} from 'faxsuite_res_tful_api';
let defaultClient = FaxsuiteResTfulApi.ApiClient.instance;

// Configure API key authorization: ApiAuthKey
let ApiAuthKey = defaultClient.authentications['ApiAuthKey'];
ApiAuthKey.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.apiKeyPrefix = 'Token';

let apiInstance = new FaxsuiteResTfulApi.JobDetailsApi();
let id = "id_example"; // String | Identification number (UUID) of the job

apiInstance.getJobNotifications(id, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Identification number (UUID) of the job | 

### Return type

[**Notifications**](Notifications.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getJobPreviews"></a>
# **getJobPreviews**
> Preview getJobPreviews(id)

/jobs/{id}/preview

Description: To obtain the preview pdf document of a specific job

### Example
```javascript
import {FaxsuiteResTfulApi} from 'faxsuite_res_tful_api';
let defaultClient = FaxsuiteResTfulApi.ApiClient.instance;

// Configure API key authorization: ApiAuthKey
let ApiAuthKey = defaultClient.authentications['ApiAuthKey'];
ApiAuthKey.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.apiKeyPrefix = 'Token';

let apiInstance = new FaxsuiteResTfulApi.JobDetailsApi();
let id = "id_example"; // String | Identification number (UUID) of the job

apiInstance.getJobPreviews(id, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Identification number (UUID) of the job | 

### Return type

[**Preview**](Preview.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getJobRecipients"></a>
# **getJobRecipients**
> JobRecipients getJobRecipients(id, opts)

/jobs/{id}/recipients

Description: Resource to obtain a list of recipients to a specific job

### Example
```javascript
import {FaxsuiteResTfulApi} from 'faxsuite_res_tful_api';
let defaultClient = FaxsuiteResTfulApi.ApiClient.instance;

// Configure API key authorization: ApiAuthKey
let ApiAuthKey = defaultClient.authentications['ApiAuthKey'];
ApiAuthKey.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.apiKeyPrefix = 'Token';

let apiInstance = new FaxsuiteResTfulApi.JobDetailsApi();
let id = "id_example"; // String | Identification number (UUID) of the job
let opts = { 
  'objectLimit': 100, // Number | Query parameter to change de default limitation of objects in the result data array
  'objectOffset': 0, // Number | Query parameter to change de default offset of objects in the result data array
  'filterFaxNumber': "filterFaxNumber_example", // String | Query parameter to fetch recipients after his fax number
  'filterFaxNumberNorm': "filterFaxNumberNorm_example", // String | Query parameter to fetch recipients after his normed fax number
  'filterRecipientReference': "filterRecipientReference_example", // String | Query parameter to fetch recipients after his recipient reference
  'filterInternationalDialingCode': "filterInternationalDialingCode_example", // String | Query parameter to fetch recipients after his international dialing code
  'filterResultCode': "filterResultCode_example", // String | Query parameter to fetch recipients after his result code
  'filterResultText': "filterResultText_example", // String | Query parameter to fetch recipients after his result text
  'sortField': "sortField_example", // String | Available sort options for the result data array.
  'sortOrder': "asc" // String | Describes the order for used sort fields
};
apiInstance.getJobRecipients(id, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Identification number (UUID) of the job | 
 **objectLimit** | **Number**| Query parameter to change de default limitation of objects in the result data array | [optional] [default to 100]
 **objectOffset** | **Number**| Query parameter to change de default offset of objects in the result data array | [optional] [default to 0]
 **filterFaxNumber** | **String**| Query parameter to fetch recipients after his fax number | [optional] 
 **filterFaxNumberNorm** | **String**| Query parameter to fetch recipients after his normed fax number | [optional] 
 **filterRecipientReference** | **String**| Query parameter to fetch recipients after his recipient reference | [optional] 
 **filterInternationalDialingCode** | **String**| Query parameter to fetch recipients after his international dialing code | [optional] 
 **filterResultCode** | **String**| Query parameter to fetch recipients after his result code | [optional] 
 **filterResultText** | **String**| Query parameter to fetch recipients after his result text | [optional] 
 **sortField** | **String**| Available sort options for the result data array. | [optional] 
 **sortOrder** | **String**| Describes the order for used sort fields | [optional] [default to asc]

### Return type

[**JobRecipients**](JobRecipients.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getJobTemplates"></a>
# **getJobTemplates**
> Templates getJobTemplates(id)

/jobs/{id}/templates

Description: To obtain a list of template documents to a specific job

### Example
```javascript
import {FaxsuiteResTfulApi} from 'faxsuite_res_tful_api';
let defaultClient = FaxsuiteResTfulApi.ApiClient.instance;

// Configure API key authorization: ApiAuthKey
let ApiAuthKey = defaultClient.authentications['ApiAuthKey'];
ApiAuthKey.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.apiKeyPrefix = 'Token';

let apiInstance = new FaxsuiteResTfulApi.JobDetailsApi();
let id = "id_example"; // String | Identification number (UUID) of the job

apiInstance.getJobTemplates(id, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Identification number (UUID) of the job | 

### Return type

[**Templates**](Templates.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="putJob"></a>
# **putJob**
> Job putJob(body, id)

/jobs/{id}

Description: Control the transmission of the specific job

### Example
```javascript
import {FaxsuiteResTfulApi} from 'faxsuite_res_tful_api';
let defaultClient = FaxsuiteResTfulApi.ApiClient.instance;

// Configure API key authorization: ApiAuthKey
let ApiAuthKey = defaultClient.authentications['ApiAuthKey'];
ApiAuthKey.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.apiKeyPrefix = 'Token';

let apiInstance = new FaxsuiteResTfulApi.JobDetailsApi();
let body = new FaxsuiteResTfulApi.JobsIdBody(); // JobsIdBody | Describes the required request body to perform an action on the fax job
let id = "id_example"; // String | Identification number (UUID) of the job

apiInstance.putJob(body, id, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**JobsIdBody**](JobsIdBody.md)| Describes the required request body to perform an action on the fax job | 
 **id** | **String**| Identification number (UUID) of the job | 

### Return type

[**Job**](Job.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

